@@ -1,4 +1,4 @@
-#!/usr/bin/python2.4
+#!/usr/bin/env python2.4
 
 from optparse import OptionParser, OptionGroup
 from sys import argv, exit
@@ -45,7 +45,7 @@ pyvcd._setOneway('startserver')
 
 try:
     hosts = pyvcd.hosts
-except PyvcError, e:
+except pyVCError, e:
     print "## %s ##" % e.hostname
     print e.value
     exit(-1)
@@ -72,7 +72,7 @@ else:
 
     try:
         (consolehost, consoleport) = pyvcd.initserver(vm)
-    except PYVCDError, e:
+    except pyVCdError, e:
         print e.value
         exit(-1)
 
