@@ -1,4 +1,4 @@
-#!/usr/bin/python2.4
+#!/usr/bin/env python2.4
 
 from optparse import OptionParser, OptionGroup
 from sys import argv, exit
@@ -30,7 +30,7 @@ pyvcd = Pyro.core.getAttrProxyForURI(uri)
 rc = "success"
 try:
     rc = pyvcd.stop()
-except PyvcError, e:
+except pyVCError, e:
     print "## %s ##" % e.hostname
     print e.value
     exit(-1)
