@@ -12,7 +12,7 @@ localhost = Machine()
 lan1 = VDE1([localhost], "lan1")
 
 # create disk image
-root = Image([localhost], imagefile = "/sandbox/image.img")
+root = Image([localhost], path = "/sandbox/image.img")
 
 # create 2 virtual machines
 qemu1 = QEMU(localhost, "qemu1", networks = [lan1], disks = [root])
