@@ -16,7 +16,7 @@ lan1 = VDE1([localhost], "lan1")
 lan2 = VDE1([localhost], "lan2")
 
 # create disk image
-root = Image([localhost], imagefile = "/sandbox/image.img")
+root = Image([localhost], path = "/sandbox/image.img")
 
 # create 2 virtual machines
 qemu1 = QEMU(localhost, "qemu1", networks = [lan1], disks = [root])
