@@ -7,7 +7,7 @@ from pyVC.Disks.Image import Disk as Image
 
 localhost = Machine()
 lan1 = Multicast([localhost], "lan1")
-root = Image([localhost], imagefile = "/Users/zach/pyvc/images/image.img")
+root = Image([localhost], path = "/Users/zach/pyvc/images/image.img")
 qemu1 = QEMU(localhost, "qemu1", networks = [lan1], disks = [root], macaddr=[QEMU.macs.next()])
 qemu2 = QEMU(localhost, "qemu2", networks = [lan1], disks = [root], macaddr=[QEMU.macs.next()])
 
