@@ -45,26 +45,26 @@ class Network( Base.Network ):
         else:
             mac_command = ""
 
-        if self.realmachine.qemu_version in ["0.8.0", "0.8.1", "0.8.2"]:
-            user_command = "-net nic%s -net user,hostname=%s" % (mac_command, host.vmname)
-            return ("", user_command, "")
-        elif self.realmachine.qemu_version in ["0.7.0", "0.7.1", "0.7.2"]:
+        if self.realmachine.qemu_version in ["0.7.0", "0.7.1", "0.7.2"]:
             user_command = "-user-net"
             return ("", user_command, "")
         else:
-            raise NetworkError, \
-                  ( "ERROR: Unhandled Network type for QEMU version %s." % \
-                    (self.realmachine.qemu_version), \
-                    2, \
-                    self.realmachine.hostname, \
-                    self.lanname \
-                  )
+            user_command = "-net nic%s -net user,hostname=%s" % (mac_command, host.vmname)
+            return ("", user_command, "")
+        #else:
+        #    raise NetworkError, \
+        #          ( "ERROR: Unhandled Network type for QEMU version %s." % \
+        #            (self.realmachine.qemu_version), \
+        #            2, \
+        #            self.realmachine.hostname, \
+        #            self.lanname \
+        #          )
 
     def uml(self, host):
         raise NotImplementedError
 
     def xen(self, host):
-        from elementtree.ElementTree import Element, SubElement
+        from lxml.etree import Element, SubElement
         interface = Element('interface', type='user')
         if host.macaddrs:
             mac = host.macaddrs.pop(0)
