@@ -1,4 +1,4 @@
-#!/usr/bin/python2.4 -i
+#!/usr/bin/env python2.4 -i
 
 from getopt import getopt, GetoptError
 from sys import argv, exit
@@ -28,4 +28,4 @@ Pyro.core.initClient(0)
 uri = "PYROLOC://%s:%s/%s" % (host, port, object)
 pyvcd = Pyro.core.getAttrProxyForURI(uri)
 
-print pyvcd.machines
+print "pyvcd.machines:", pyvcd.machines
