@@ -1,6 +1,7 @@
-#!/usr/bin/python2.4
+#!/usr/bin/env python2.4
 
-from lxml.etree import XMLSchema, parse, XMLSyntaxError, XMLSchemaParseError
+from lxml.etree import XML, XMLSchema, parse, XMLSyntaxError, XMLSchemaParseError
+from pkg_resources import resource_string
 from sys import argv, exit
 from pyVC import Config
 
@@ -14,7 +15,8 @@ if 'vcml_schema' not in config['pyvc']:
   print "ERROR: schema path not in pyVC.ini"
 
 try:
-  schemafile = parse( config['pyvc']['vcml_schema'] )
+  schematext = resource_string('pyVC', 'vcml.xsd')
+  schemafile = XML( schematext )
 except IOError:
   print "ERROR: could not open schema file %s." % config['pyvc']['vcml_schema']
   exit(-1)
